##
## Figure 1: Terrestrial species with maximum occurrence reports by population group
##

species_threats_raw <- readr::read_csv(master_threats_csv_fn)
names(species_threats_raw)
#
if(!('popgroupmax' %in% names(species_threats_raw))){
  species_threats_raw <- species_threats_raw %>%
    dplyr::rename(.,popgroupmax = maxcut)
}

# Land or Land_Coast
mterrdata=species_threats_raw %>%
  # terrestrial
  dplyr::filter(lcat %in% c('Land','Land_Coast')) %>%
  dplyr::select(species,popgroupmax) %>%
  distinct()
dim(mterrdata)

# summarize species count from each popgroup
species_maxcut <- mterrdata %>%
  dplyr::group_by(popgroupmax) %>%
  dplyr::summarise(n_species = n())

dim(species_maxcut)
sum(species_maxcut$n_species)

# plot
require(ggplot2)
p1 <-  ggplot(data=species_maxcut, aes(x=popgroupmax, y=n_species)) +
  geom_line(color="grey") +
  geom_point(shape=21, color="black", fill="red", size=2) + 
  scale_y_continuous(labels = scales::comma)+
  scale_x_continuous(labels = as.character(1:15), breaks = 1:15)+
  xlab("Population Group") + 
  ylab("Species in Group")
  
fig1_fn <- file.path(figdir,paste0('fig_01_terrestrial_species_with_maxcut_occurrence_reports',
                                   '_ddh',ddh_vers,
                                   'run',run_vers,'.png'))
ggsave(fig1_fn,p1,dpi=300,width = 5, height = 4.2, units = "in")


fig1data_fn <- file.path(figdir,paste0('fig_01_terrestrial_species_with_maxcut_occurrence_reports',run_vers,'.csv'))
write.csv(species_maxcut,fig1data_fn,row.names=F)

sum(species_maxcut$n_species)