###################################################################
##
## Figure 4 : Plants and vertebrates: global cell totals for model-predicted
## threat probabilities, all GBIF Species
##
###################################################################

##
## Input
##

##
## use boundary data
## source(file.path(wkdir,'biod_threats_wp_load_boundary_data.R'))
##

##
## use gridded species data
## source(file.path(wkdir,'biod_threats_wp_load_gridded_data_ddh.R'))
##

## read IUCN
##gbifiucn_fn <- 'T:/gbif/GBIF_Indicators_Data_Full/GBIF_Merged_IUCN_Risks.csv'
gbifiucn <- readr::read_csv(master_threats_csv_fn)
if(!('group' %in% names(gbifiucn))){
  gbifiucn <- gbifiucn %>%
    dplyr::rename(.,group = grp)
}
if(!('tprob' %in% names(gbifiucn))){
  gbifiucn <- gbifiucn %>%
    dplyr::rename(.,tprob = pthreat)
}



gbifiucn <- gbifiucn %>%
  dplyr::select(species,irisk,group,area,tprob)

dim(gbifiucn)
table(gbifiucn$group)
print(sprintf("Species without IUCN rating: %s",sum(is.na(gbifiucn$irisk))))
print(sprintf("Species with IUCN rating: %s",sum(!is.na(gbifiucn$irisk))))

# fixed no Animals_Other in species group : Plants and Vertebrates
spp_groups <- c('Plants_Asparagales','Plants_Asterales','Plants_Caryophyllales','Plants_Ericales',
                'Plants_Fabales','Plants_Gentianales','Plants_Lamiales','Plants_Malpighiales',
                'Plants_Myrtales','Plants_Other','Plants_Poales','Amphibians','Birds',
                'Fish','Mammals','Reptiles')

# extract Plants and Vertebrates Only
spp_irisk_full <- gbifiucn %>%
  dplyr::filter(group %in% spp_groups)
print(sprintf("Total Plants and vertebrates species : %s",sum(dim(spp_irisk_full)[1])))

# add tprob at species level
#species_threats_fn <- file.path('T:/gbif/GBIF_Indicators_Data_Full','GBIF Species Threats.csv')
#species_tprob <- fread(species_threats_fn) %>%
#  dplyr::select(species,tprob)
#dim(species_tprob)

# Plants and Animals ONLY = YES
table(spp_irisk_full$group)

# merge All plants and vertebrates from merged data with tprob table
#spp_risks_full_plt_vert <- merge(spp_irisk_full,species_tprob,by="species",all.x=TRUE)
spp_risks_full_plt_vert <- spp_irisk_full

print(sprintf("Total Plants and vertebrates species merged: %s",dim(spp_risks_full_plt_vert)[1]))
print(sprintf("Total Plants and vertebrates species with tprob: %s",sum(!is.na(spp_risks_full_plt_vert$tprob))))
print(sprintf("Total Plants and vertebrates species without tprob: %s",sum(is.na(spp_risks_full_plt_vert$tprob))))

# subset to full gbif only of plants and vertebrates
spp_risks_full_gbif_matched <- spp_risks_full_plt_vert %>%
  dplyr::filter(!is.na(tprob)) %>%
  dplyr::select(species,tprob) %>%
  as.data.table()

# Convert to data.table, efficient
dt <- data.table(totresult)

# Filter the dataset by species
totresult_sub <- dt[species %in% spp_risks_full_gbif_matched$species]

# merge 
spp_obs_full_plt_vert <- totresult_sub[spp_risks_full_gbif_matched,on="species",allow.cartesian = TRUE]

##
## dissolve cell x species into cell level
## tprob index
##
data.table::setDTthreads(threads = 16)
spp_full_plt_vert_result <- spp_obs_full_plt_vert %>%
  dplyr::filter(!is.na(value)) %>%
  dplyr::filter(!is.na(tprob)) %>%
  dplyr::group_by(value) %>%
  dplyr::summarize(species_sum_gbif = sum(tprob,na.rm=TRUE)) %>%
  ungroup() %>%
  dplyr::mutate(max_species_gbif_sum = max(species_sum_gbif,na.rm=T)) %>%
  dplyr::group_by(value) %>%
  dplyr::mutate(species_tprob_index = (species_sum_gbif / max_species_gbif_sum) * 100) %>%
  dplyr::select(value,species_tprob_index)

# global grid
r4 <- terra::rast(resolution = 0.25)
r4[spp_full_plt_vert_result[,1]] <- spp_full_plt_vert_result[,2]
names(r4)<-'spp_full_gbif_tprob'

r4_fn <- file.path(wkdir,'local_data',sprintf("vers%s",ddh_vers), 
                   paste0('fig_04_Threat_Status_GBIF_Plants_and_Vertebrates_tprob_full_gbif',
                          '_ddh',ddh_vers,
                          'run',run_vers,'.tif'))
if (!dir.exists(dirname(r4_fn))) {dir.create(dirname(r4_fn),recursive = TRUE)}
terra::writeRaster(r4,r4_fn,overwrite=TRUE)

# Projection stack
require(stars)
biod_alloc_stars <- st_as_stars(r4,name= "attributes")

# reproject
biod_alloc_stars_prj <- st_transform(biod_alloc_stars,crs=eckertIV)

# warp so it's no curvilinear
#require(FNN)
biod_alloc_stars_prj = st_warp(biod_alloc_stars_prj, crs = eckertIV,
                               cellsize = 20000,threshold=25000,
                               method = "near")

##
## breaks 
##
temp <- c(biod_alloc_stars_prj$spp_full_gbif_tprob) %>% as.numeric()

temp <- temp[!is.na(temp) & temp>0]
temp_decile = cut(temp, breaks=c(quantile(temp, probs = seq(0, 1, by = 0.10))))
temp_decile_breaks <- sapply(strsplit(levels(temp_decile), "\\(|,|]"), function(x) as.numeric(x[-1]))
vBreaks <- c(temp_decile_breaks[1,],temp_decile_breaks[2,10])

##
## numeric to factor for maps
##
biod_labels = c("1st","2nd","3rd","4th","5th","6th","7th","8th","9th","10th")

biod_alloc_stars_prj$fbiod_index_full_gbif_tprob <- cut(biod_alloc_stars_prj$spp_full_gbif_tprob,
                                                      breaks=vBreaks,
                                                      labels = biod_labels,
                                                      include.lowest=TRUE, right=TRUE)
biod_alloc_stars_prj$fbiod_index_full_gbif_tprob <- factor(biod_alloc_stars_prj$fbiod_index_full_gbif_tprob,
                                                         levels = biod_labels,
                                                         labels = biod_labels)

biod_hex <- c("#EBEBEB",RColorBrewer::brewer.pal(9,"PuBuGn"))

windowsFonts("Arial" = windowsFont("Arial"))
## theme from 2022-05-11, modified for R&R
## https://www.r-craft.org/r-news/how-to-create-a-beautiful-map-with-r-and-geom_sf-part-2/
mytheme <- theme(text = element_text(family = 'Arial')
                 ,panel.background = element_rect(fill = 'white')
                 ,plot.title = element_text(size = 32)
                 ,plot.subtitle = element_text(size = 14)
                 ,axis.title = element_blank()
                 ,axis.text = element_blank()
)

biod_alloc_stars_prj_sub <- biod_alloc_stars_prj[c("fbiod_index_full_gbif_tprob")]

# figure ready names
names(biod_alloc_stars_prj_sub) <- 'Biodiversity Index Value'
#  c('Global cell sum for model-predicted threat probabilities, IUCN species match')

# From attributes to dimension
biod_alloc_stars_prj_sub_re = st_redimension(biod_alloc_stars_prj_sub)
names(biod_alloc_stars_prj_sub_re) = "value"
table(biod_alloc_stars_prj_sub_re$value)
biod_alloc_stars_prj_sub_re
biod_alloc_stars_prj_sub_re$group <- names(biod_alloc_stars_prj_sub)

lineT<- c("countries"="solid", "disputed" = "dotdash","ocean" = "solid")

# Define custom labeller function
custom_labeller <- function(variable, value) {
  value
}

# plot... models with same legend
p4 <- ggplot() +
  # alpha transparency parameter for smoothing curvilinear polygons
  geom_stars(data = biod_alloc_stars_prj_sub_re, alpha = 0.9) +
  # stars color fill
  scale_fill_manual(breaks = biod_labels, values = biod_hex, na.value = "white",
                    name = "Biodiversity Index Value",
                    guide = guide_legend(ncol=5,
                                         direction = "horizontal",
                                         title.position = "top",
                                         title.hjust =0.5
                    )) +
  geom_sf(data=bnd0, aes(linetype = bndtype, color = colortype), fill = NA,
          lwd=0.1,show.legend = FALSE) +
  scale_color_manual(values = c("land" = "gray80","ocean"="#ADD8E6"))+
  scale_linetype_manual(values = lineT) +
  coord_sf()+
  mytheme +
  # drop axis labels per reviewer comment
  theme(legend.position="bottom",
        axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks = element_blank()) +
  theme(legend.key = element_rect(fill = "white")) +
  theme(strip.background =element_rect(fill="gray92"))

p4_fn <- file.path(figdir,paste0('fig_04_Global_cell_totals_for_model-predicted_threat_prob_all_GBIF_Plants_Vertebrates_Species',
                                 '_ddh',ddh_vers,
                                 'run',run_vers,'.png'))
ggsave(p4_fn,p4,dpi=500,width = 7,height = 4.2,units='in')

## clean-up
rm(dt)
rm(biod_alloc_stars,biod_alloc_stars_prj,p4)
rm(r4)
gc()
