####################################################################
##
## Figure 6: LC assignment vs species occurrence region scale
##
####################################################################

print("caution plyr must be loaded before dplyr")
print("can cause group_by to not function properly 2024-08-24")

# read IUCN
gbifiucn <- readr::read_csv(master_threats_csv_fn)
if(!('group' %in% names(gbifiucn))){
  gbifiucn <- gbifiucn %>%
    dplyr::rename(.,group = grp)
}
if(!('tprob' %in% names(gbifiucn))){
  gbifiucn <- gbifiucn %>%
    dplyr::rename(.,tprob = pthreat)
}

spp_risks_full <- gbifiucn %>%
  #dplyr::select(species,irisk,area) #%>%
  dplyr::select(species,irisk,tprob,area)

print(sprintf("Total species with IUCN and tprob: %s",sum(!is.na(spp_risks_full$irisk)&!is.na(spp_risks_full$tprob))))
spp_risks_full <- spp_risks_full %>%
  dplyr::filter(!is.na(irisk) & !is.na(tprob))
dim(spp_risks_full)

area_breaks <- c(0,seq(5, 200,by=5)^2,max(spp_risks_full$area,na.rm=T))
label_breaks <- c(0,seq(5, 200,by=5))

# use species area and bin by 1x1, 5, 10, 50
print("plyr package causes incorrect proportions must detach")
#detach("package:caret", unload = TRUE)
require(dplyr)

species_tab_grid_scale <- spp_risks_full %>%
  dplyr::mutate(area_categories = (cut(area,area_breaks,include.lowest=T,
                                      label_breaks))) %>%
  dplyr::mutate(irisk_lc = ifelse(irisk=="1LC",1,0)) %>%
  dplyr::select(area_categories,irisk_lc)%>%
  dplyr::group_by(area_categories)%>% 
  dplyr::count(irisk_lc) %>% 
  mutate(prc = prop.table(n)*100) %>%
  dplyr::rename(Count = n) %>%
  dplyr::mutate(Range_size = as.numeric(as.character(area_categories))) %>%
  # drop 0 category and 200+ category (only show species with smaller areas)
  dplyr::filter(Range_size!=0 & Range_size!=200) %>%
  # percent of species rate least concern only
  dplyr::filter(irisk_lc==1)

dim(spp_risks_full)  
tail(species_tab_grid_scale)

# Create the plot
p6 <- ggplot(data=species_tab_grid_scale, aes(x=Range_size, y=prc)) +
  #geom_line(color="grey") +
  geom_point(shape=21, color="black", fill="red", size=2) + 
  xlab("Species Occurrence Map Scale (km)") + 
  ylab("Percent of Species Rated Least Concern")

fig6_fn <- file.path(figdir,paste0('fig_06_LC_assignment_vs_range_scale','_ddh',ddh_vers,
                                   'run',run_vers,'.png'))
ggsave(fig6_fn,p6,dpi=300,width = 5, height = 4.2, units = "in")

fig6data_fn <- file.path(figdir,paste0('fig_06_LC_assignment_vs_range_scale',
                                       '_ddh',ddh_vers,
                                       'run',run_vers,'.csv'))
write.csv(species_tab_grid_scale,fig6data_fn,row.names=F)
