###################################################################
##
## Figure 7: Plants and vertebrates: Global cell totals for model 
## predictions by threat group
##
###################################################################

##
## Input
##

##
## use boundary data
## source(file.path(wkdir,'biod_threats_wp_load_boundary_data.R'))
##

##
## use gridded species data
## source(file.path(wkdir,'biod_threats_wp_load_gridded_data_ddh.R'))
##

# read IUCN
##gbifiucn_fn <- 'T:/gbif/GBIF_Indicators_Data_Full/GBIF_Merged_IUCN_Risks.csv'
gbifiucn <- readr::read_csv(master_threats_csv_fn)
if(!('group' %in% names(gbifiucn))){
  gbifiucn <- gbifiucn %>%
    dplyr::rename(.,group = grp)
}
if(!('tprob' %in% names(gbifiucn))){
  gbifiucn <- gbifiucn %>%
    dplyr::rename(.,tprob = pthreat)
}



dim(gbifiucn)
table(gbifiucn$group)
print(sprintf("Species without IUCN rating: %s",sum(is.na(gbifiucn$irisk))))
print(sprintf("Species with IUCN rating: %s",sum(!is.na(gbifiucn$irisk))))

# fixed no Animals_Other in species group : Plants and Vertebrates
spp_groups <- c('Plants_Asparagales','Plants_Asterales','Plants_Caryophyllales','Plants_Ericales',
                'Plants_Fabales','Plants_Gentianales','Plants_Lamiales','Plants_Malpighiales',
                'Plants_Myrtales','Plants_Other','Plants_Poales','Amphibians','Birds',
                'Fish','Mammals','Reptiles')

# extract Plants and Vertebrates Only
spp_irisk_full <- gbifiucn %>%
  dplyr::filter(group %in% spp_groups)

print(sprintf("Total Plants and vertebrates species : %s",sum(dim(spp_irisk_full)[1])))

# how many plant and vertebrates in IUCN? Drop DD
print(sprintf("Total Plants and vertebrates species with IUCN rating: %s",sum(!is.na(spp_irisk_full$irisk))))
print(sprintf("Total Plants and vertebrates species without IUCN rating: %s",sum(is.na(spp_irisk_full$irisk))))

# 1LC   2NT   3VU   4EN   5CR 
# 53261  5067  8592  7878  2797 = 77595
table(spp_irisk_full$irisk)

# add tprob at species level
#species_threats_fn <- file.path('T:/gbif/GBIF_Indicators_Data_Full','GBIF Species Threats.csv')
#species_tprob <- fread(species_threats_fn) %>%
#  dplyr::select(species,tprob)
#dim(species_tprob)

# Plants and Animals ONLY = YES
table(spp_irisk_full$group)

# merge All plants and vertebrates from merged data with tprob table
spp_risks_full_plt_vert <- spp_irisk_full
#spp_risks_full_plt_vert <- merge(spp_irisk_full,species_tprob,by="species",all.x=TRUE)

# bins
spp_risks_full_plt_vert_tprobdec <- spp_risks_full_plt_vert %>%
  dplyr::filter(!is.na(tprob)) %>%
  dplyr::mutate(tprob_20bins = as.integer(cut(tprob, breaks=c(quantile(tprob, probs = seq(0, 1, by = 0.05)))))) %>%
  dplyr::select(species,tprob_20bins) %>%
  as.data.table()

table(spp_risks_full_plt_vert_tprobdec$tprob_20bins)

# Convert to data.table, efficient
dt <- data.table(totresult)

# Filter the dataset by species
totresult_sub <- dt[species %in% spp_risks_full_plt_vert_tprobdec$species]

# merge plants and vertebrates into grid cells by species
spp_obs_full_plt_vert_tprobdec <- totresult_sub[spp_risks_full_plt_vert_tprobdec,on='species',allow.cartesian = TRUE]
#spp_obs_full_plt_vert_tprobdec <- merge(totresult_sub,spp_risks_full_plt_vert_tprobdec,by='species')

spp_full_plt_vert_tprobdec <- spp_obs_full_plt_vert_tprobdec %>%
  dplyr::filter(!is.na(value)) %>%
  #dplyr::filter(!is.na(tprob_20bins)) %>%
  # decile 1- 600 tprob into group, score 1-20
  # sum of score for grid cells / max 
  dplyr::arrange(value) %>%
  dplyr::group_by(value) %>%
  dplyr::summarize(species_sum_tprob_dec = sum(tprob_20bins,na.rm=TRUE)) %>%
  ungroup() %>%
  dplyr::mutate(max_species_sum_tprob_dec = max(species_sum_tprob_dec,na.rm=T)) %>%
  dplyr::group_by(value) %>%
  dplyr::mutate(species_tprob_20bins = (species_sum_tprob_dec / max_species_sum_tprob_dec) * 100) %>%
  dplyr::select(value,species_tprob_20bins)

r7 <- terra::rast(resolution = 0.25)
r7[spp_full_plt_vert_tprobdec[,1]] <- spp_full_plt_vert_tprobdec[,2]
r7_fn <- file.path(wkdir,'local_data',sprintf("vers%s",ddh_vers),
                   paste0('fig_07_Tprob_by_threat_group_all_GBIF_Plants_Vertebrates_Species_Global_cell_totals_for_Tprob_by_threat_group',
                          '_ddh',ddh_vers,
                          'run',run_vers,'.tif'))
#names(r7)<-'spp_plt_vert_tprob_20bins'
r7[r7==0] <- NA
names(r7) <- 'biod_plt_vert_tprob_threatgrp'
terra::writeRaster(r7,r7_fn,overwrite=TRUE)

# Projection stack
require(stars)
biod_alloc_stars <- st_as_stars(r7,name= "attributes")

# reproject
biod_alloc_stars_prj <- st_transform(biod_alloc_stars,crs=eckertIV)
st_bbox(biod_alloc_stars_prj)

# warp so it's no curvilinear
#require(FNN)
biod_alloc_stars_prj = st_warp(biod_alloc_stars_prj, crs = eckertIV,
                               cellsize = 20000,threshold=25000,
                               method = "near")

##
## breaks 
##
temp <- c(biod_alloc_stars_prj$biod_plt_vert_tprob_threatgrp) %>% 
  as.numeric()
temp <- temp[!is.na(temp) & temp>0]
temp_decile = cut(temp, breaks=c(quantile(temp, probs = seq(0, 1, by = 0.10))))
table(temp_decile)
temp_decile_breaks <- sapply(strsplit(levels(temp_decile), "\\(|,|]"), function(x) as.numeric(x[-1]))
temp_decile_breaks[1,]
vBreaks <- c(temp_decile_breaks[1,1],temp_decile_breaks[2,])

##
## numeric to factor for maps
##
biod_labels = c("1st","2nd","3rd","4th","5th","6th","7th","8th","9th","10th")
                
biod_alloc_stars_prj$fspp_plt_vert_tprob_20bins <- cut(biod_alloc_stars_prj$biod_plt_vert_tprob_threatgrp, 
                      vBreaks, 
                      labels = biod_labels,
                      include.lowest=TRUE, right=TRUE)
biod_alloc_stars_prj$fspp_plt_vert_tprob_20bins <- factor(biod_alloc_stars_prj$fspp_plt_vert_tprob_20bins,
                                           levels = biod_labels,
                                           labels = biod_labels)
table(biod_alloc_stars_prj$fspp_plt_vert_tprob_20bins)

biod_hex <- c("#EBEBEB",RColorBrewer::brewer.pal(9,"YlOrRd"))

windowsFonts("Arial" = windowsFont("Arial"))
## theme from 2022-05-11, modified for R&R
## https://www.r-craft.org/r-news/how-to-create-a-beautiful-map-with-r-and-geom_sf-part-2/
mytheme <- theme(text = element_text(family = 'Arial')
                 ,panel.background = element_rect(fill = 'white')
                 ,plot.title = element_text(size = 32)
                 ,plot.subtitle = element_text(size = 14)
                 ,axis.title = element_blank()
                 ,axis.text = element_blank()
)

# subset factor attributes
biod_alloc_stars_prj_sub <- biod_alloc_stars_prj[c("fspp_plt_vert_tprob_20bins")]

# figure ready names
names(biod_alloc_stars_prj_sub) <- c('fspp_plt_vert_tprob_20bins')

# From attributes to dimension
biod_alloc_stars_prj_sub_re = st_redimension(biod_alloc_stars_prj_sub)
names(biod_alloc_stars_prj_sub_re) = "value"
table(biod_alloc_stars_prj_sub_re$value)
biod_alloc_stars_prj_sub_re

lineT<- c("countries"="solid", "disputed" = "dotdash","ocean" = "solid")
table(bnd0$bndtype)
table(bnd0$colortype)

# Define custom labeller function
custom_labeller <- function(variable, value) {
  value
}

# plot... models with same legend
p7 <- ggplot() +
  # alpha transparency parameter for smoothing curvilinear polygons
  geom_stars(data = biod_alloc_stars_prj_sub_re, alpha = 0.9) +
  # stars color fill
  scale_fill_manual(breaks = biod_labels, values = biod_hex, na.value = "white",
                    name = "Biodiversity Index Value",
                    guide = guide_legend(ncol=5,
                                         direction = "horizontal",
                                         title.position = "top",
                                         title.hjust =0.5
                    )) +
  geom_sf(data=bnd0, aes(linetype = bndtype, color = colortype), fill = NA,
          lwd=0.1,show.legend = FALSE) +
  scale_color_manual(values = c("land" = "gray80","ocean"="#ADD8E6"))+
  scale_linetype_manual(values = lineT) +
  coord_sf()+
  mytheme +
  # drop axis labels per reviewer comment
  theme(legend.position="bottom",
        axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks = element_blank()) +
  theme(legend.key = element_rect(fill = "white")) +
  theme(strip.background =element_rect(fill="gray92"))

p7_fn <- file.path(figdir,paste0('fig_07_Tprob_by_threat_group_all_GBIF_Plants_Vertebrates_Species',
                                 '_ddh',ddh_vers,
                                 'run',run_vers,'.png'))
ggsave(p7_fn,p7,dpi=500,width = 7,height = 4.2,units='in')

# clean-up
rm(totresult_sub)
rm(p7)
rm(biod_alloc_stars_prj)
rm(spp_obs_full_plt_vert_tprobdec)
rm(spp_full_plt_vert_tprobdec)