###################################################################
##
## Figure 9: Plants and vertebrates: Western South America:  
## Effect of priority reassignment for small species occurrence region species
##
###################################################################

##
## Input
##

##
## use boundary data
## source(file.path(wkdir,'biod_threats_wp_load_boundary_data.R'))
##

##
## use gridded species data
## source(file.path(wkdir,'biod_threats_wp_load_gridded_data_ddh.R'))
##


r7_fn <- file.path(wkdir,'local_data',sprintf("vers%s",ddh_vers),
                   paste0('fig_07_Tprob_by_threat_group_all_GBIF_Plants_Vertebrates_Species_Global_cell_totals_for_Tprob_by_threat_group',
                          '_ddh',ddh_vers,
                          'run',run_vers,'.tif'))
r7 <- terra::rast(r7_fn)
names(r7) <- 'biod_tprob_priority'

r8_fn <- file.path(wkdir,'local_data',sprintf("vers%s",ddh_vers),
                    paste0('fig_08_Normalized_Plants_Vertebrates_Global_cell_totals_for_Stacked_AB_by_threat_group',
                           '_ddh',ddh_vers,
                           'run',run_vers,'.tif'))
r8 <- terra::rast(r8_fn)
names(r8) <- 'biod_tprob_stacked_priority'

# Projection stack
require(stars)
biod_alloc_stars <- st_as_stars(r7,as_attributes = TRUE)
# reproject
biod_alloc_stars2 <- st_transform(biod_alloc_stars,crs=eckertIV)
st_bbox(biod_alloc_stars2)

# warp so it's no curvilinear
require(FNN)
biod_alloc_stars_prj7 = st_warp(biod_alloc_stars2, crs = eckertIV,
                               cellsize = 20000,threshold=25000,
                               method = "near")

biod_alloc_stars <- st_as_stars(r8,as_attributes = TRUE)
# reproject
biod_alloc_stars2 <- st_transform(biod_alloc_stars,crs=eckertIV)
st_bbox(biod_alloc_stars2)

# warp so it's no curvilinear
require(FNN)
biod_alloc_stars_prj8 = st_warp(biod_alloc_stars2, crs = eckertIV,
                                cellsize = 20000,threshold=25000,
                                method = "near")


# stack grids
biod_alloc_stars_prj <- c(biod_alloc_stars_prj7,biod_alloc_stars_prj8)
names(biod_alloc_stars_prj) <- c('biod_tprob_priority','biod_tprob_stacked_priority')

##
## breaks 
##
temp <- c(biod_alloc_stars_prj$biod_tprob_priority,biod_alloc_stars_prj$biod_tprob_stacked_priority) %>%  as.numeric()
temp <- temp[!is.na(temp) & temp>0]
temp_decile_breaks <- round(quantile(temp, probs = seq(0, 1, by = 0.10)),2)
temp_decile = cut(temp, breaks=c(quantile(temp, probs = seq(0, 1, by = 0.10))))
table(temp_decile)
temp_decile_breaks <- sapply(strsplit(levels(temp_decile), "\\(|,|]"), function(x) as.numeric(x[-1]))
vBreaks <- c(temp_decile_breaks[1,1],temp_decile_breaks[2,])

##
## numeric to factor for maps
##
biod_labels = c("1st","2nd","3rd","4th","5th","6th","7th","8th","9th","10th")

biod_alloc_stars_prj$fbiod_tprob_priority <- cut(biod_alloc_stars_prj$biod_tprob_priority,
                                                             breaks=vBreaks,
                                           labels = biod_labels,
                                           include.lowest=TRUE, right=TRUE)
biod_alloc_stars_prj$fbiod_tprob_priority <- factor(biod_alloc_stars_prj$fbiod_tprob_priority,
                                           levels = biod_labels,
                                           labels = biod_labels)
table(biod_alloc_stars_prj$fbiod_tprob_priority)

biod_alloc_stars_prj$fbiod_tprob_stacked_priority <- cut(biod_alloc_stars_prj$biod_tprob_stacked_priority, 
                           vBreaks,
                           labels = biod_labels,
                           include.lowest=TRUE, right=TRUE)
biod_alloc_stars_prj$fbiod_tprob_stacked_priority <- factor(biod_alloc_stars_prj$fbiod_tprob_stacked_priority,
                                                         levels = biod_labels,
                                                         labels = biod_labels)

table(biod_alloc_stars_prj$fbiod_tprob_stacked_priority)

biod_hex <- c("#EBEBEB",RColorBrewer::brewer.pal(9,"YlOrRd"))

windowsFonts("Arial" = windowsFont("Arial"))
## theme from 2022-05-11, modified for R&R
## https://www.r-craft.org/r-news/how-to-create-a-beautiful-map-with-r-and-geom_sf-part-2/
mytheme <- theme(text = element_text(family = 'Arial')
                 ,panel.background = element_rect(fill = 'white')
                 ,plot.title = element_text(size = 32)
                 ,plot.subtitle = element_text(size = 14)
                 ,axis.title = element_blank()
                 ,axis.text = element_blank()
)

# subset factor attributes
biod_alloc_stars_prj_sub <- biod_alloc_stars_prj[c("fbiod_tprob_priority","fbiod_tprob_stacked_priority")]

# figure ready names
names(biod_alloc_stars_prj_sub) <- 
  c('Panel a: Model-based prediction',
    'Panel b: After priority reassignment for small range species')

# From attributes to dimension
biod_alloc_stars_prj_sub_re = st_redimension(biod_alloc_stars_prj_sub)
names(biod_alloc_stars_prj_sub_re) = "value"
table(biod_alloc_stars_prj_sub_re$value)
biod_alloc_stars_prj_sub_re
biod_alloc_stars_prj_sub_re$group <- names(biod_alloc_stars_prj_sub)

lineT<- c("countries"="solid", "disputed" = "dotdash","ocean" = "solid")
table(bnd0$bndtype)
table(bnd0$colortype)

# Define custom labeller function
custom_labeller <- function(variable, value) {
  value
}

# bounding box 
n<-23
s<--10
w<--107
e<--65
bbox_sa <-pgirmess::bbox2sf(n,s,e,w)
bbox_sa0 <- st_transform(bbox_sa,eckertIV) %>% st_as_sf()
st_bbox(bbox_sa0)

# plot... models with same legend
p09 <- ggplot() +
  # alpha transparency parameter for smoothing curvilinear polygons
  geom_stars(data = biod_alloc_stars_prj_sub_re, alpha = 0.9) +
  # stars color fill
  scale_fill_manual(breaks = biod_labels, values = biod_hex, na.value = "white",
                    name = "Biodiversity Index Value",
                    guide = guide_legend(ncol=5,
                                         direction = "horizontal",
                                         title.position = "top",
                                         title.hjust =0.5
                    )) +
  geom_sf(data=bnd0, aes(linetype = bndtype, color = colortype), fill = NA,
          lwd=0.1,show.legend = FALSE) +
  scale_color_manual(values = c("land" = "gray80","ocean"="#ADD8E6"))+
  scale_linetype_manual(values = lineT) +
  coord_sf(xlim = c(st_bbox(bbox_sa0)$xmin, st_bbox(bbox_sa0)$xmax), 
           ylim = c(st_bbox(bbox_sa0)$ymin, st_bbox(bbox_sa0)$ymax))+
  mytheme +
  # drop axis labels per reviewer comment
  theme(legend.position="bottom",
        axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks = element_blank()) +
  theme(legend.key = element_rect(fill = "white")) +
  theme(strip.background =element_rect(fill="gray92"))+
  facet_wrap(new_dim ~ ., ncol=2, strip.position="top",
             labeller = label_wrap_gen(multi_line = TRUE,width=110))

p09_fn <- file.path(figdir,paste0('fig_09_GBIF_Plants_and_Vertebrates_Western_South_America',
                                  '_ddh',ddh_vers,
                                  'run',run_vers,'.png'))
ggsave(p09_fn,p09,dpi=500,width = 8,height = 5.4,units='in')

# clean-up
rm(p09,biod_alloc_stars_prj_sub_re,biod_alloc_stars_prj_sub,biod_alloc_stars_prj,biod_alloc_stars_prj8,biod_alloc_stars_prj7)