###################################################################
##
## Figure 10: Plants and vertebrates: differences in global cell totals for 
## model-predictions after priority reassignment for 
## small species occurrence region species
##
###################################################################

##
## Input
##

##
## use boundary data
## source(file.path(wkdir,'biod_threats_wp_load_boundary_data.R'))
##

##
## use gridded species data
## source(file.path(wkdir,'biod_threats_wp_load_gridded_data_ddh.R'))
##


# PROJ.4 string for Eckert IV projection
eckertIV <- "+proj=eck4 +lon_0=0 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs" 

n<-90
s<--90
w<--180
e<-180
globe0<-pgirmess::bbox2sf(n,s,e,w)


r7_fn <- file.path(wkdir,'local_data',sprintf("vers%s",ddh_vers),
                   paste0('fig_07_Tprob_by_threat_group_all_GBIF_Plants_Vertebrates_Species_Global_cell_totals_for_Tprob_by_threat_group',
                          '_ddh',ddh_vers,
                          'run',run_vers,'.tif'))
r7 <- terra::rast(r7_fn)
names(r7) <- 'biod_tprob_priority'

r8_fn <- file.path(wkdir,'local_data',sprintf("vers%s",ddh_vers),
                   paste0('fig_08_Normalized_Plants_Vertebrates_Global_cell_totals_for_Stacked_AB_by_threat_group',
                          '_ddh',ddh_vers,
                          'run',run_vers,'.tif'))
r8 <- terra::rast(r8_fn)
names(r8) <- 'biod_tprob_stacked_priority'


r10 = r8 - r7
r10_fn <- file.path(wkdir,'local_data',sprintf("vers%s",ddh_vers),
                    paste0('fig_10_Diff_Plants_Vertebrates_Global_cell_totals_Tprob_for_Stacked_AB_by_threat_group',
                           '_ddh',ddh_vers,
                           'run',run_vers,'.tif'))
names(r10)<-'spp_dif_plt_vert_tprob_vs_stackedAB_20bins'
terra::writeRaster(r10,r10_fn,overwrite=TRUE)
names(r10) <- 'biod_dif_tprob_vs_stacked'

# Projection stack
require(stars)
biod_alloc_stars <- st_as_stars(r10,name= "attributes")

# split bands to attributes
biod_alloc_stars2 <- biod_alloc_stars
attributes(biod_alloc_stars2)

# reproject
biod_alloc_stars_prj <- st_transform(biod_alloc_stars2,crs=eckertIV)
st_bbox(biod_alloc_stars_prj)

# warp so it's no curvilinear
#require(FNN)
biod_alloc_stars_prj = st_warp(biod_alloc_stars_prj, crs = eckertIV,
                               cellsize = 20000,threshold=25000,
                               method = "near")

##
## breaks 
##
max_biod_count <- max(biod_alloc_stars_prj$biod_dif_tprob_vs_stacked,na.rm=T) %>% as.numeric()
min_biod_count <- min(biod_alloc_stars_prj$biod_dif_tprob_vs_stacked,na.rm=T) %>% as.numeric()

tempmin <- c(biod_alloc_stars_prj$biod_dif_tprob_vs_stacked)
tempmin <- tempmin[!is.na(tempmin) & tempmin<0]
tempmin_decile = cut(tempmin, breaks=c(quantile(tempmin, probs = seq(0, 1, by = 0.20))))
table(tempmin_decile)
tempmin_decile_breaks <- sapply(strsplit(levels(tempmin_decile), "\\(|,|]"), function(x) as.numeric(x[-1]))
tempmin_decile_breaks[1,]

tempmax <- c(biod_alloc_stars_prj$biod_dif_tprob_vs_stacked)
tempmax <- tempmax[!is.na(tempmax) & tempmax>0]
tempmax_decile = cut(tempmax, breaks=c(quantile(tempmax, probs = seq(0, 1, by = 0.20))))
table(tempmax_decile)
tempmax_decile_breaks <- sapply(strsplit(levels(tempmax_decile), "\\(|,|]"), function(x) as.numeric(x[-1]))
tempmax_decile_breaks[2,]

vBreaks <- c(tempmin_decile_breaks[1,], -0.001, 0.001, tempmax_decile_breaks[2,])

biod_alloc_stars_prj$fbiod_dif_tprob_vs_stacked <- cut(biod_alloc_stars_prj$biod_dif_tprob_vs_stacked, 
                      vBreaks, 
                      include.lowest=TRUE, right=TRUE)

biod_alloc_stars_prj$fbiod_dif_tprob_vs_stacked <- factor(biod_alloc_stars_prj$fbiod_dif_tprob_vs_stacked)
levels(biod_alloc_stars_prj$fbiod_dif_tprob_vs_stacked)
table(biod_alloc_stars_prj$fbiod_dif_tprob_vs_stacked)

#biod_hex <- c("#EBEBEB",RColorBrewer::brewer.pal(9,"YlOrRd"))
#RColorBrewer::display.brewer.pal(10,"YlOrRd")

windowsFonts("Arial" = windowsFont("Arial"))
## theme from 2022-05-11, modified for R&R
## https://www.r-craft.org/r-news/how-to-create-a-beautiful-map-with-r-and-geom_sf-part-2/
mytheme <- theme(text = element_text(family = 'Arial')
                 ,panel.background = element_rect(fill = 'white')
                 ,plot.title = element_text(size = 32)
                 ,plot.subtitle = element_text(size = 14)
                 ,axis.title = element_blank()
                 ,axis.text = element_blank()
)

# subset factor attributes
biod_alloc_stars_prj_sub <- biod_alloc_stars_prj[c("fbiod_dif_tprob_vs_stacked")]

# figure ready names
names(biod_alloc_stars_prj_sub) <- c('Biodiversity Difference')

# From attributes to dimension
biod_alloc_stars_prj_sub_re = st_redimension(biod_alloc_stars_prj_sub)
names(biod_alloc_stars_prj_sub_re) = "value"
table(biod_alloc_stars_prj_sub_re$value)
biod_alloc_stars_prj_sub_re

lineT<- c("countries"="solid", "disputed" = "dotdash","ocean" = "solid")

##
## plot difference discrete
##
# subset factor attributes
biod_alloc_stars_prj_sub <- biod_alloc_stars_prj[c("fbiod_dif_tprob_vs_stacked")]

# figure ready names
names(biod_alloc_stars_prj_sub) <- c('Biodiversity Difference')

# From attributes to dimension
biod_alloc_stars_prj_sub_re = st_redimension(biod_alloc_stars_prj_sub)
names(biod_alloc_stars_prj_sub_re) = "value"

# discrete map
p10disc <- ggplot() +
  geom_stars(data = biod_alloc_stars_prj_sub_re) +
  scale_fill_brewer(palette = 'RdYlBu',
    aesthetics = 'fill',
    na.value = "grey97",
    guide = guide_legend()
  ) +
  geom_sf(data=bnd0, aes(linetype = bndtype, color = colortype), fill = NA,
          lwd=0.1,show.legend = FALSE) +
  scale_color_manual(values = c("land" = "gray80","ocean"="#ADD8E6"))+
  scale_linetype_manual(values = lineT) +
  guides(fill = guide_legend(nrow = 3,
                             title = "Biodiversity Index value Difference", 
                             theme(legend.title.position = "top",
                                   legend.position="bottom",
                                   legend.title = element_text(0.5),
                                   legend.box="horizontal")))+
  labs(x = NULL,y = NULL)+
  coord_sf()
  # drop axis labels per reviewer comment
  
p10disc <- p10disc + theme(legend.position="bottom") +
  theme(axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks = element_blank(),
        legend.key = element_rect(fill = "white"),
        plot.background = element_rect(fill = "white"),
        strip.background =element_rect(fill="gray92"))

p10disc_fn <- file.path(figdir,paste0('fig_10_GBIF_dif_Tprob_vs_stacked_Plants_and_Vertebrates_species_discrete',
                                      '_ddh',ddh_vers,
                                      'run',run_vers,'.png'))
ggsave(p10disc_fn,p10disc,dpi=300,width = 7, height = 4.2, units = "in")
