####################################################################
##
## boundary file : countries, disputed and coastline
##
####################################################################

# PROJ.4 string for Eckert IV projection
eckertIV <- "+proj=eck4 +lon_0=0 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs" 

# boundary directory
bnddir <- file.path(wkdir,'local_data','Boundary_Data_50mil')

bnd0ocean_fn <- file.path(bnddir,'ne_50m_WB_coastline.shp')
bnd0ocean <- read_sf(bnd0ocean_fn) %>%
  dplyr::mutate(bndtype = "ocean",
                colortype = "ocean")

# country level boundaries #
bnd_fn <- file.path(bnddir,'ne_50m_WB_admin_0_boundary_lines.shp')
bndctr <- read_sf(bnd_fn)  %>%
  dplyr::mutate(bndtype="countries",
                colortype="land")

# disputated boundaries
bnddisp_fn <- file.path(bnddir,'ne_50m_WB_admin_0_boundary_lines_disputed.shp')
bnddisp <- read_sf(bnddisp_fn) %>%
  dplyr::mutate(bndtype="disputed",
                colortype="land") %>%
  st_cast(.,"MULTILINESTRING")

# bind together
bnd_dt <- data.table::rbindlist(list(bndctr,bnddisp,bnd0ocean),fill=TRUE)

# back to sf
bnd <- st_sf(bnd_dt)

# make valid
bnd <- bnd %>% st_make_valid() %>% st_cast(.,"MULTILINESTRING")

# reproject
bnd0 <- st_transform(bnd,eckertIV) %>% st_as_sf()
