#########################################################################
## Input: species occurrence regions
##    global grid
##
## Output: 
##   Summarize information at global grid levels for figure production
##   Paper #2
##
#############################################################


#masterddh <- "T:/gbif/GBIF_Species_Master_DDH"
masterddh <- file.path(wkdir,'local_data','gbif_master_ddh')
xfun::dir_create(masterddh)

r0_fn <- file.path(masterddh,'global_biod_species_grid.csv')
if(!file.exists(r0_fn)){
   # download file from DDH
   # URL of the data file on World Bank Development Hub
   url <- 'https://datacatalogfiles.worldbank.org/ddh-published/0066034/DR0094184/global_biod_species_grid.csv'

   # Extract the file name from the URL
   file_name <- basename(url)

     # Extra header to be included in the request
     extra_header <- "versionId=2024-05-14T16:35:04.1082518Z"

     # Send the request
     response <- GET(url, add_headers(extra_header))

     # Check the response status
     if (http_status(response)$category == "Success") {

       # Save the file
       writeBin(content(response, "raw"), r0_fn)

       cat("File downloaded successfully!", r0_fn)
     } else {
       cat("Error downloading file:", http_status(response)$message)
     }

 } else {
   r0_csv <- read.csv(r0_fn)
 }

#r0 <- terra::rast(r0_csv)

## load csv with species X global raster ID in species occurrence region only
totresult_fn <- file.path(masterddh,"global_biod_species_level_grid.rar")
if(!file.exists(totresult_fn)){
  # download from DDH
  url2 <- 'https://datacatalogfiles.worldbank.org/ddh-published/0066034/DR0094185/global_biod_species_level_grid.rar'
  
  # Extract the file name from the URL
  file_name <- basename(url2)
  
  # Extra header to be included in the request
  extra_header <- "versionId=2024-07-23T15:39:13.2086329Z"
  
  # Send the request
  response <- httr::GET(url2, add_headers(extra_header))
  
  # Check the response status
  if (http_status(response)$category == "Success") {
    
    # Save the file
    writeBin(content(response, "raw"), totresult_fn)
    
    cat("File downloaded successfully!", totresult_fn)
  } else {
    cat("Error downloading file:", http_status(response)$message)
  }
  
}

require(R.utils)
print("Loading grid cell X species data")
# requires extracted file #
extract_dir = file.path(masterddh, 'temp')
xfun::dir_create(extract_dir)

local_gridded_data_fn <- file.path(extract_dir,sprintf('global_biod_species_level_grid_ddh%s.csv',ddh_vers))
if(!file.exists(local_gridded_data_fn)){
  archive::archive_extract(totresult_fn, dir = extract_dir)
  print("extracted file")
  # rename 
  raw_local_gridded_data_fn <- file.path(extract_dir,'global_biod_species_level_grid.csv')
  file.rename(raw_local_gridded_data_fn,local_gridded_data_fn)
}
system.time(totresult <- readr::read_csv(local_gridded_data_fn))
print("Loaded grid cell X species data")

