idir=file.path(wkdir,'local_data')

#### Download and Unzip the Latest GBIF File for IUCN Red List Data

# Define the URL of the zip file
url <- "https://hosted-datasets.gbif.org/datasets/iucn/iucn-latest.zip"

# Define the local file name where you want to save the downloaded zip file
local_file <- sprintf("iucn-latest-download-%s.zip",Sys.Date())

fn=file.path(idir,local_file)

# Download the zip file
download.file(url, fn, mode = "wb")

# Unzip the downloaded file
unzip(fn, exdir = idir)

#### Extract Species IDs and IUCN Risk Information

dn=file.path(idir,"distribution.txt")
ddata=read_tsv(dn,col_names=FALSE)
fdata=as.data.frame(ddata)
xdt=fdata[,c("X1","X4")]
names(xdt)=c("specid","exrisk")
xdt$specid=as.numeric(xdt$specid)
setorder(xdt,specid)

#### Extract Species IDs and Species Names 

dn=file.path(idir,"taxon.txt")
ddata=read_tsv(dn,col_names=FALSE)
fdata=as.data.frame(ddata)
setorder(fdata,X1)
gdata=fdata[,c("X1","X8","X9")]
xtt=subset(gdata,!is.na(X8))
names(xtt)=c("specid","sn1","sn2")
xtt$species=paste0(xtt$sn1," ",xtt$sn2)
xtt[c("sn1","sn2")]=NULL
xtt$specid=as.numeric(xtt$specid)
setorder(xtt,specid)

#### Extract Species IDs, Vernacular Names and Vernacular Languages

dn=file.path(idir,"vernacularname.txt")
ddata=read_tsv(dn,col_names=FALSE)
fdata=as.data.frame(ddata)
gdata=fdata[,c("X1","X2","X3")]
names(gdata)=c("specid","lang","cname")
gdata$specid=as.numeric(gdata$specid)
xt=as.data.frame(table(gdata$lang))
names(xt)=c("lang","freq")
mxd=merge(gdata,xt,by=c("lang"))
setorder(mxd,specid)
# careful to load dplyr functions here
dmax=as.data.frame(mxd %>%
     dplyr::group_by(specid) %>%
     dplyr::summarize(maxfreq = max(freq,na.rm=TRUE)))
mmxd=left_join(mxd,dmax,by="specid")
xmm=subset(mmxd,freq==maxfreq)
# careful to load dplyr functions here
fmm <- xmm %>%
  dplyr::group_by(specid) %>%
  dplyr::slice(1)
xvt=as.data.frame(fmm[,c("specid","lang","cname")])

#### Merge the Extraction Files

m1=merge(xdt,xtt,by="specid",all.x=TRUE)
m2=merge(m1,xvt,by="specid",all.x=TRUE)
m2$exrisk=str_to_title(m2$exrisk)

#### Retain Species with IUCN Ratings in the Five Conventional Categories

mfile=subset(m2,exrisk %in% c("Least Concern","Near Threatened","Vulnerable","Endangered","Critically Endangered"))

mfile <- mfile %>%
  mutate(irisk = case_when(
    exrisk == "Least Concern" ~ "1LC",
    exrisk == "Near Threatened" ~ "2NT",
    exrisk == "Vulnerable" ~ "3VU",
    exrisk == "Endangered" ~ "4EN",
    exrisk == "Critically Endangered" ~ "5CR",
    TRUE ~ NA_character_
  ))

mdata=as.data.frame(mfile)
mdata$iscore=1*(mdata$irisk=="1LC")+2*(mdata$irisk=="2NT")+3*(mdata$irisk=="3VU")+4*(mdata$irisk=="4EN")+5*(mdata$irisk=="5CR")
tmdata=data.table(mdata[,c("species","irisk","iscore","cname")]) # updated with cname
setorder(tmdata,species,-iscore)
ndm=tmdata[!duplicated(tmdata$species)]

# read in citation
data <- xmlParse(file.path(idir,"eml.xml"))
xml_data <- xmlToList(data)
citation <- xml_data$additionalMetadata$metadata$gbif$citation
# IUCN extract version
print(sprintf("iucn version %s",iucn_vers))
iucn_version <- str_sub(strsplit(citation, "\\.")[[1]][3],start= -6)
print("iucn version")
iucn_citation_fn <- file.path(wkdir,'local_data',sprintf("vers%s",ddh_vers),sprintf("GBIF_IUCN_Red_List%s_citation.csv",iucn_version))
write.csv(citation,iucn_citation_fn,row.names=FALSE)
print(citation)

mname=file.path(wkdir,'local_data',sprintf("vers%s",ddh_vers),sprintf("GBIF_IUCN_Red_List%s.csv",iucn_version))
data.table::fwrite(ndm,mname,row.names=FALSE)
