################################################################################
##
## Requires species at IUCN risk
## Download species level data from DDH and load
##
################################################################################

species_iucn_fn=file.path(wkdir,'local_data',sprintf("vers%s",ddh_vers),sprintf("GBIF_IUCN_Red_List%s.csv",iucn_version))
if(!file.exists(species_iucn_fn)) {
  print("requires local data")
}

species_tab_fn <- file.path(wkdir,'local_data',sprintf("vers%s",ddh_vers), "GBIF_Merged_IUCN_Risks_Tab.csv")

if(!file.exists(species_tab_fn)){
  
  # download latest ddh version #
  if(ddh_vers!='2024-02-19'){
  
    # URL of the data file on World Bank Development Hub
    url <- 'https://datacatalogfiles.worldbank.org/ddh-published/0066034/DR0094182/global_biod_species_extinction_risks.csv'
    
    # Extract the file name from the URL
    file_name <- basename(url)
    species_threats_fn = file.path(ddhdir, basename(file_name))
    
    if(!file.exists(species_threats_fn)){
      
      # Extra header to be included in the request
      if(ddh_vers=='2024-05-14'){extra_header <- "versionId=2024-05-14T16:35:04.1082518Z"}
      if(ddh_vers=='2024-08-12'){extra_header <- "versionId=2024-08-12T13:19:51.3962026Z"}
      
      # Send the request
      response <- GET(url, add_headers(extra_header))
      
      # Check the response status
      if (http_status(response)$category == "Success") {
        
        # Save the file
        writeBin(content(response, "raw"), species_threats_fn)
        
        cat("File downloaded successfully!",species_threats_fn)
      } else {
        cat("Error downloading file:", http_status(response)$message)
      }
    } 
    
    species_threats_raw <- readr::read_csv(species_threats_fn)
    
    # URL of the data file on World Bank Development Hub
    url2 <- 'https://datacatalogfiles.worldbank.org/ddh-published/0066034/DR0094183/global_biod_species_occ_endemism_and_small_range.csv'
    
    # Extract the file name from the URL
    file_name <- basename(url2)
    species_occ_fn = file.path(ddhdir, basename(file_name))
    
    if(!file.exists(species_occ_fn)){
      
      # Extra header to be included in the request
      if(ddh_vers=='2024-05-14'){extra_header <- "versionId=2024-05-14T16:35:06.8856710Z"}
      if(ddh_vers=='2024-08-12'){extra_header <- "versionId=2024-08-12T13:19:53.3910689Z"}
      
      # Send the request
      response <- GET(url2, add_headers(extra_header))
      
      # Check the response status
      if (http_status(response)$category == "Success") {
        
        # Save the file
        writeBin(content(response, "raw"), species_occ_fn)
        
        cat("File downloaded successfully!",species_occ_fn)
        
        species_occ_raw <- readr::read_csv(species_occ_fn)
        
      } else {
        cat("Error downloading file:", http_status(response)$message)
      }
    }
    
    species_occ_raw <- readr::read_csv(species_occ_fn)
    
    # species and order
    species_occ <- species_occ_raw %>%
      dplyr::select(species,order,grp,area)
    dim(species_occ)
    
    # rename col
    species_threats0 <- species_threats_raw %>%
      dplyr::rename(.,maxcut = popgroupmax)
    dim(species_threats0)
    
    # add irisk (private - not republished)
    species_irisk <- readr::read_csv(species_iucn_fn)
    dim(species_irisk)
    
    # merge, add irisk
    species_threats <- merge(species_threats0,species_irisk,by="species",all.x=T)
    dim(species_threats)
    
    # merge datasets
    species_tab <- merge(species_occ,species_threats,by="species")
    dim(species_tab)
    names(species_tab)
    
    species_tab$location="Ocean"
    species_tab$location[species_tab$lcat %in% c("Land","Land_Coast")] ="Land"
    table(species_tab$location)
    species_tab$spclass="Other"
    species_tab$spclass[grepl("Plants",species_tab$grp)]="Plants"
    # species_tab$spclass[species_tab$group %in% c("Amphibians","Mammals","Reptiles","Birds","Fish")]="Vertebrates"
    # species_tab$rcat[species_tab$location=="Land" & species_tab$spclass=="Vertebrates"]="Land_Vertebrates"
    species_tab$rcat[species_tab$location=="Land" & species_tab$spclass=="Other"]="Land_Other"
    species_tab$rcat[species_tab$location=="Land" & species_tab$spclass=="Plants"]="Land_Plants"
    species_tab$rcat[species_tab$location=="Land" & species_tab$grp=="Mammals"]="Land_Mammals"
    species_tab$rcat[species_tab$location=="Land" & species_tab$grp=="Amphibians"]="Land_Amphibians"
    species_tab$rcat[species_tab$location=="Land" & species_tab$grp=="Birds"]="Land_Birds"
    species_tab$rcat[species_tab$location=="Land" & species_tab$grp=="Reptiles"]="Land_Reptiles"
    species_tab$rcat[species_tab$location=="Land" & species_tab$grp=="Fish"]="Land_Fish"
    
    species_tab$rcat[species_tab$location=="Ocean"]="Ocean_Other"
    species_tab$rcat[species_tab$location=="Ocean" & species_tab$grp=="Fish"]="Ocean_Fish"
    
    table(species_tab$rcat)
    
    # ensure unique
    species_tab <- species_tab %>% distinct()
    
    # create dir and write data 
    xfun::dir_create(dirname(species_tab_fn),recursive = TRUE)
    readr::write_csv(species_tab,species_tab_fn)
    names(species_tab)
  
  } else {
  
    ## First version ## 
    print(sprintf("use %s version",ddh_vers))
    
    species_occ_fn <- file.path(wkdir,'local_data',sprintf("vers%s",ddh_vers),'GBIF_Merged_IUCN_Risks_tab.csv')
    species_occ_raw <- readr::read_csv(species_occ_fn)
    
    species_threats_fn <- file.path(wkdir,'local_data',sprintf("vers%s",ddh_vers),'GBIF_Species_Threats_Tab.csv')
    species_threats_raw <- readr::read_csv(species_threats_fn) %>%
      dplyr::mutate(tprob=tprob* 100) %>%
      dplyr::select(species,tprob)
    
    # species and order
    species_occ <- species_occ_raw %>%
      dplyr::rename(.,grp = group)
    dim(species_occ)
    
    # rename col
    species_threats <- species_threats_raw
      #dplyr::rename(.,maxcut = popgroupmax)
    #dim(species_threats0)
    
    # add irisk (private - not republished)
    #mdata2_fn <- file.path(wkdir,'local_data','species_IUCN_risks.csv')
    #species_irisk <- readr::read_csv(mdata2_fn)
    #dim(species_irisk)
    
    # merge, add irisk
    #species_threats <- merge(species_threats0,species_irisk,by="species",all.x=T)
    #names(species_threats)
    #dim(species_threats)
    
    # merge datasets
    species_tab <- merge(species_occ,species_threats,by=c("species"))
    dim(species_tab)
    names(species_tab)
    
    species_tab$location="Ocean"
    species_tab$location[species_tab$lcat %in% c("Land","Land_Coast")] ="Land"
    table(species_tab$location)
    species_tab$spclass="Other"
    species_tab$spclass[grepl("Plants",species_tab$grp)]="Plants"
    # species_tab$spclass[species_tab$group %in% c("Amphibians","Mammals","Reptiles","Birds","Fish")]="Vertebrates"
    # species_tab$rcat[species_tab$location=="Land" & species_tab$spclass=="Vertebrates"]="Land_Vertebrates"
    species_tab$rcat[species_tab$location=="Land" & species_tab$spclass=="Other"]="Land_Other"
    species_tab$rcat[species_tab$location=="Land" & species_tab$spclass=="Plants"]="Land_Plants"
    species_tab$rcat[species_tab$location=="Land" & species_tab$grp=="Mammals"]="Land_Mammals"
    species_tab$rcat[species_tab$location=="Land" & species_tab$grp=="Amphibians"]="Land_Amphibians"
    species_tab$rcat[species_tab$location=="Land" & species_tab$grp=="Birds"]="Land_Birds"
    species_tab$rcat[species_tab$location=="Land" & species_tab$grp=="Reptiles"]="Land_Reptiles"
    species_tab$rcat[species_tab$location=="Land" & species_tab$grp=="Fish"]="Land_Fish"
    
    species_tab$rcat[species_tab$location=="Ocean"]="Ocean_Other"
    species_tab$rcat[species_tab$location=="Ocean" & species_tab$grp=="Fish"]="Ocean_Fish"
    
    table(species_tab$rcat)
    # create dir and write data 
    xfun::dir_create(dirname(species_tab_fn),recursive = TRUE)
    readr::write_csv(species_tab,species_tab_fn)
    names(species_tab)
    
  } 
  
  
  } else {
    # load species_tab
    species_tab <- readr::read_csv(species_tab_fn)
    print(sprintf("Last modified : %s",file.info(species_tab_fn)$ctime))
  
}



##
## statistics for working paper text
##
# categorize by terrestrial / marine
table(species_tab$lcat)

# Land or Land_coast
species_tab <- species_tab %>%
  dplyr::mutate(d_terr = ifelse(lcat %in% c('Land','Land_Coast'),1,0))

#table(species_tab$d_terr)
df1 <- as.data.frame(table(species_tab$d_terr))
names(df1)[1] <- 'Species_domain'
names(df1)[2] <- 'Number_of_species'
levels(df1$Species_domain)
df1 <- df1 %>%
  mutate(., Species_domain = forcats::fct_recode(Species_domain, "Terrestrial" = "1", "Marine" = "0"))
print(df1)
df1_fn <- file.path(tbldir,sprintf('WPS_text_Species_terr_or_marine%s.csv',Sys.Date()))
write.csv(df1,df1_fn,row.names=FALSE)

##
## IUCN merged
##
#table(species_tab_iucn_merge$gbif_iucn_merge)
species_tab_iucn_merge <- species_tab %>%
  dplyr::mutate(gbif_iucn_merge = ifelse(!is.na(irisk),1,0)) %>%
  distinct() %>%
  group_by(gbif_iucn_merge) %>%
  summarize(species_gbif_iucn_merge = n()) %>%
  as.data.frame()

df2_fn <- file.path(tbldir,sprintf('WPS_text_Species_IUCN_merged_%s.csv',Sys.Date()))
write.csv(species_tab_iucn_merge,df2_fn,row.names=FALSE)
