##########################################################
##
## Table 1: Correlations between predictive model variables
##
## Table 2: Ordered logit results for IUCN Red List categories
##
## former P9 Generate Species Risk Factors and Predicted Threats
##
##########################################################


#### Load the Information Produced by P7 Generate Database for Regressions
#### Group All Species Into 5 Categories for Fitting Ordered Logit Regressions

# load species level data
species_tab_fn <- file.path(wkdir,'local_data',sprintf("vers%s",ddh_vers), "GBIF_Merged_IUCN_Risks_Tab.csv")

mdata=readr::read_csv(species_tab_fn)
names(mdata)
      
dmdata=as.data.frame(mdata)
dmdata$location="Ocean"
dmdata$location[dmdata$lcat %in% c("Land","Land_Coast")] ="Land"
dmdata$spclass="Other"
dmdata$spclass[grepl("Plants",dmdata$grp)]="Plants"
# dmdata$spclass[dmdata$group %in% c("Amphibians","Mammals","Reptiles","Birds","Fish")]="Vertebrates"
# dmdata$rcat[dmdata$location=="Land" & dmdata$spclass=="Vertebrates"]="Land_Vertebrates"
dmdata$rcat[dmdata$location=="Land" & dmdata$spclass=="Other"]="Land_Other"
dmdata$rcat[dmdata$location=="Land" & dmdata$spclass=="Plants"]="Land_Plants"
dmdata$rcat[dmdata$location=="Land" & dmdata$grp=="Mammals"]="Land_Mammals"
dmdata$rcat[dmdata$location=="Land" & dmdata$grp=="Amphibians"]="Land_Amphibians"
dmdata$rcat[dmdata$location=="Land" & dmdata$grp=="Birds"]="Land_Birds"
dmdata$rcat[dmdata$location=="Land" & dmdata$grp=="Reptiles"]="Land_Reptiles"
dmdata$rcat[dmdata$location=="Land" & dmdata$grp=="Fish"]="Land_Fish"

dmdata$rcat[dmdata$location=="Ocean"]="Ocean_Other"
dmdata$rcat[dmdata$location=="Ocean" & dmdata$grp=="Fish"]="Ocean_Fish"
table(dmdata$rcat)

rc=c("Land_Amphibians","Land_Birds","Land_Mammals","Land_Reptiles","Land_Fish","Land_Plants","Land_Other","Ocean_Fish","Ocean_Other")

#### Processing for Terrestrial Species

dndata=subset(dmdata,rcat %in% c("Land_Amphibians","Land_Birds","Land_Mammals","Land_Reptiles","Land_Fish","Land_Plants","Land_Other"))
dndata$order[is.na(dndata$order)]="NotAssigned"


rland=c("Land_Amphibians","Land_Birds","Land_Mammals","Land_Reptiles","Land_Fish","Land_Plants","Land_Other","Land_Vertebrates")
# add Vertebrates for presentation purposes ONLY
#rland=c("Land_Vertebrates","Land_Plants","Land_Other")  ## 2024-03-28
rlandvertebrates <- c("Land_Amphibians","Land_Birds","Land_Mammals","Land_Reptiles","Land_Fish")

xmcmb=data.frame()

# MODEL LIST
models_terrestrial <- list()
models_terrestrial_full_r2 <- list()

for (i in 1:length(rland)) {
    
  rname=rland[i] 
  print(rname)
  
  if(rname=='Land_Vertebrates'){
    print("model ALL land vertebrates together")
    
    xmdata=subset(dndata,rcat %in% rlandvertebrates)
    #xmdata$rcat[xmdata$rcat %in% rlandvertebrates] <- 'Land_Vertebrates'
    
  } else {
    xmdata=subset(dndata,rcat==rname)
  }
  
  
  #### Construction of Model Variable V1 From Range Area 
  
  xmdata$nxside=ceiling((xmdata$area)^0.5)
  xmdata$lnxside=log(xmdata$nxside)
  xmdata$v1=xmdata$lnxside
  mxv1=max(xmdata$v1,na.rm=TRUE)
  xmdata$dv1=mxv1-xmdata$v1
  mx1=max(xmdata$dv1,na.rm=TRUE)
  xmdata$nfactor1=100*xmdata$dv1/mx1
  xmdata$factor1="Range Size"
  xmdata[,c("mxv1","dv1","mx1")]=NULL
  
  #### Construction of Model Variable V2 From Settlement Sensitivity
  
  xmdata$v2=log(xmdata$maxcut)
  mxv2=max(xmdata$v2,na.rm=TRUE)
  xmdata$dv2=mxv2-xmdata$v2
  mx2=max(xmdata$dv2,na.rm=TRUE)
  xmdata$nfactor2=100*xmdata$dv2/mx2
  xmdata$factor2="Settlement Sensitivity"
  xmdata[,c("mxv2","dv2","mx2")]=NULL
  
  #### Construction of Model Variable V3 From Population Density
  
  # rename columns as necessary #
  
  #xmdata$v3=log(xmdata$popdens+1)
  xmdata$v3=log(xmdata$popden+1)
  mx3=max(xmdata$v3,na.rm=TRUE)
  xmdata$v3=as.numeric(xmdata$v3)
  xmdata$nfactor3=100*xmdata$v3/mx3
  xmdata$factor3="Population Density"
  xmdata[,c("mx3")]=NULL
  
  #### Construction of Model Variable V4 From Formal Protection Status
  
  xmdata$nparkpct=100*xmdata$parkpct
  xmdata$nparkpct[xmdata$nparkpct<1]=1
  xmdata$v4=log(xmdata$nparkpct)
  mxv4=max(xmdata$v4,na.rm=TRUE)
  xmdata$dv4=mxv4-xmdata$v4
  mx4=max(xmdata$dv4,na.rm=TRUE)
  xmdata$nfactor4=100*xmdata$dv4/mx4
  xmdata$factor4="Formal Protection"
  xmdata[,c("mxv4","dv4","mx4")]=NULL
  
  tcounts=as.data.frame(table(xmdata$order))
  names(tcounts)=c("order","freq")
  xtcounts=subset(tcounts,order!="NotAssigned")
  xtcounts=subset(xtcounts,freq>=100)
  
  vor=xtcounts$order
  unique_order <- vor
  
  #### Create Dummy Variables for All Species Orders With At Least 100 Observations
  
  for (order_name in unique_order) {
    dv <- ifelse(xmdata$order == order_name, 1, 0)
    dv[is.na(dv)]=0
    dvname <- paste("d_", order_name, sep = "_")
    xmdata[dvname] <- dv
  }
  
  dvnames <- grep("^d_", names(xmdata), value = TRUE)
  
  #### Create Full Interaction Terms For Model Variables V1 to V4
  
  xmdata <- xmdata %>%
    mutate(
      cp_v1_v2 = v1 * v2,
      cp_v1_v3 = v1 * v3,
      cp_v1_v4 = v1 * v4,
      cp_v2_v3 = v2 * v3,
      cp_v2_v4 = v2 * v4,
      cp_v3_v4 = v3 * v4,
      cp_v1_sq = v1^2,
      cp_v2_sq = v2^2,
      cp_v3_sq = v3^2,
      cp_v4_sq = v4^2
    )
  
  dvcross=grep("^cp_", names(xmdata), value = TRUE)
  
  #### Create IUCN-Based Risk Scores for Ordered Logit Regression
  
  xmdata$iscore <- factor(xmdata$irisk, levels = c("1LC","2NT","3VU", "4EN", "5CR"))
  
  xmdata$irisk=as.numeric(xmdata$iscore)
  
  #### Estimate Simple and Fully-Specified Risk Models
  
  rfact1="irisk ~ v1 + v2 + v3 + v4"
  rfact=paste("irisk ~ v1 + v2 + v3 + v4 +",paste(dvnames, collapse = " + "),"+",paste(dvcross, collapse = " + "))
  
  model <- lm(rfact1, xmdata)
  summary(model)
  
  models_terrestrial[[i]] <- model
  
  model <- lm(rfact, xmdata)
  summary(model)
  
  models_terrestrial_full_r2[[i]] <- summary(model)$r.squared
  
  coefs<- coef(model)
  mcoefs <- data.frame(variable = names(coefs), coef = coefs)
  xmc=subset(mcoefs,is.na(coef))
  xv=xmc$variable
  
  #### Identify Collinear Species Order Dummy Variables to Exclude From Ordered Logit Estimation
  
  dxnames=dvnames[!dvnames %in% xv]
  
  #### Estimate the Ordered Logit Model
  
  rfact=paste("iscore ~ v1 + v2 + v3 + v4 +",paste(dxnames, collapse = " + "),"+",paste(dvcross, collapse = " + "))
  # rfact=paste("iscore ~ ",paste(dxnames, collapse = " + "),"+",paste(dvcross, collapse = " + "))
  
  #mm=polr(iscore ~ v1 + v2 + v3 + v4 , data = xmdata, Hess = TRUE)
  #summary(mm)
  
  m=MASS::polr(rfact, data = xmdata, Hess = TRUE)
  
  ## EDIT ##
  
  if(!(rname %in% rlandvertebrates)){
    #### Predict Threat Probabilities For All Species in the Set"
    
    pprob <- predict(m, xmdata, type = "probs")
    zmdata=cbind(xmdata,pprob)
    zmdata$tprob <- rowSums(zmdata[, c("2NT","3VU", "4EN", "5CR")])
    zmdata$pthreat=plyr::round_any(100*zmdata$tprob,1)
    #xzm=zmdata[,c("lcat","rcat","gdir","species","tprob","pthreat","nfactor1","factor1","nfactor2","factor2","nfactor3","factor3","nfactor4","factor4")]
    xzm=zmdata[,c("lcat","rcat","species","tprob","pthreat","nfactor1","factor1","nfactor2","factor2","nfactor3","factor3","nfactor4","factor4")]
    
    xmcmb=rbind(xmcmb,xzm)
    } else {
     #### Processing for Vertebrates group for presentation purposes ONLY
     #### tprob will take advantage of all subgroups
     print("Processing for Vertebrates group for presentation purposes ONLY")
     print("vertebrates prediction is at subgroup level")
  }
    
}



#### Processing for Ocean Fish Species
models_marine_full_r2 <- list()

xmdata=subset(dmdata,rcat=="Ocean_Fish")

xmdata$order[is.na(xmdata$order)]="NotAssigned"

#### Construction of Model Variable V1 From Range Area 

xmdata$nxside=ceiling((xmdata$area)^0.5)
xmdata$lnxside=log(xmdata$nxside)
xmdata$v1=xmdata$lnxside
mxv1=max(xmdata$v1,na.rm=TRUE)
xmdata$dv1=mxv1-xmdata$v1
mx1=max(xmdata$dv1,na.rm=TRUE)
xmdata$nfactor1=100*xmdata$dv1/mx1
xmdata$factor1="Range Size"
xmdata[,c("mxv1","dv1","mx1")]=NULL

#### Construction of Model Variable V2 From EEZ Coverage

xmdata$neezpct=100*xmdata$eezpct
xmdata$neezpct[xmdata$neezpct<1]=1
xmdata$v2=log(xmdata$neezpct)
mxv2=max(xmdata$v2,na.rm=TRUE)
xmdata$dv2=mxv2-xmdata$v2
mx2=max(xmdata$dv2,na.rm=TRUE)
xmdata$nfactor2=100*xmdata$dv2/mx2
xmdata$factor2="EEZ Coverage"
xmdata[,c("mxv2","dv2","mx2")]=NULL

#### Construction of Model Variable V3 From Fishing Intensity (1)

xmdata$v3=log(xmdata$totfishing+1)
mx3=max(xmdata$v3,na.rm=TRUE)
xmdata$v3=as.numeric(xmdata$v3)
xmdata$nfactor3=100*xmdata$v3/mx3
xmdata$factor3="Fishing Intensity (1)"
xmdata[,c("mx3")]=NULL

#### Construction of Model Variable V4 From Fishing Intensity (2)

xmdata$nnatfishing=100*xmdata$natfishing
xmdata$nnatfishing[xmdata$nnatfishing<1]=1
xmdata$v4=log(xmdata$nnatfishing)
mx4=max(xmdata$v4,na.rm=TRUE)
xmdata$v4=as.numeric(xmdata$v4)
xmdata$nfactor4=100*xmdata$v4/mx4
xmdata$factor4="Fishing Intensity (2)"
xmdata[,c("mx4")]=NULL

tcounts=as.data.frame(table(xmdata$order))
names(tcounts)=c("order","freq")
xtcounts=subset(tcounts,order!="NotAssigned")
xtcounts=subset(xtcounts,freq>=100)

vor=xtcounts$order
unique_order <- vor

#### Create Dummy Variables for All Species Orders With At Least 100 Observations

for (order_name in unique_order) {
  dv <- ifelse(xmdata$order == order_name, 1, 0)
  dv[is.na(dv)]=0
  dvname <- paste("d_", order_name, sep = "_")
  xmdata[dvname] <- dv
}

dvnames <- grep("^d_", names(xmdata), value = TRUE)

#### Create Full Interaction Terms For Model Variables V1 to V4

xmdata <- xmdata %>%
  mutate(
    cp_v1_v2 = v1 * v2,
    cp_v1_v3 = v1 * v3,
    cp_v1_v4 = v1 * v4,
    cp_v2_v3 = v2 * v3,
    cp_v2_v4 = v2 * v4,
    cp_v3_v4 = v3 * v4,
    cp_v1_sq = v1^2,
    cp_v2_sq = v2^2,
    cp_v3_sq = v3^2,
    cp_v4_sq = v4^2
  )

dvcross=grep("^cp_", names(xmdata), value = TRUE)

#### Create IUCN-Based Risk Scores for Ordered Logit Regression

xmdata$iscore <- factor(xmdata$irisk, levels = c("1LC","2NT","3VU", "4EN", "5CR"))

xmdata$irisk=as.numeric(xmdata$iscore)

#### Estimate Simple and Fully-Specified Risk Models

rfact1="irisk ~ v1 + v2 + v3 + v4"
rfact=paste("irisk ~ v1 + v2 + v3 + v4 +",paste(dvnames, collapse = " + "),"+",paste(dvcross, collapse = " + "))

model <- lm(rfact1, xmdata)
summary(model)

## add
model_Ocean_Fish0 <- model

model <- lm(rfact, xmdata)
summary(model)

## add
model_Ocean_Fish1 <- model

models_marine_full_r2[1] <- summary(model)$r.squared

coefs<- coef(model)
mcoefs <- data.frame(variable = names(coefs), coef = coefs)
xmc=subset(mcoefs,is.na(coef))
xv=xmc$variable

#### Identify Collinear Species Order Dummy Variables to Exclude From Ordered Logit Estimation

dxnames=dvnames[!dvnames %in% xv]

#### Estimate the Ordered Logit Model

if (length(dxnames)==0) {
  rfact=paste("iscore ~ v1 + v2 + v3 + v4 +",paste(dvcross, collapse = " + ")) 
} else {
  rfact=paste("iscore ~ v1 + v2 + v3 + v4 +",paste(dxnames, collapse = " + "),"+",paste(dvcross, collapse = " + "))  
}

# rfact=paste("iscore ~ v1 + v2 + v3 + v4 +",paste(dxnames, collapse = " + "),"+",paste(dvcross, collapse = " + "))
# rfact=paste("iscore ~ ",paste(dxnames, collapse = " + "),"+",paste(dvcross, collapse = " + "))

#mm=polr(iscore ~ v1 + v2 + v3 + v4 , data = xmdata, Hess = TRUE)
#summary(mm)

m=MASS::polr(rfact, data = xmdata, Hess = TRUE)
summary(m)

#### Predict Threat Probabilities For All Species in the Set"

pprob <- predict(m, xmdata, type = "probs")
zmdata=cbind(xmdata,pprob)
zmdata$tprob <- rowSums(zmdata[, c("2NT","3VU", "4EN", "5CR")])
zmdata$pthreat=plyr::round_any(100*zmdata$tprob,1)
#xzm=zmdata[,c("lcat","rcat","gdir","species","tprob","pthreat","nfactor1","factor1","nfactor2","factor2","nfactor3","factor3","nfactor4","factor4")]
xzm=zmdata[,c("lcat","rcat","species","tprob","pthreat","nfactor1","factor1","nfactor2","factor2","nfactor3","factor3","nfactor4","factor4")]

xmcmb=rbind(xmcmb,xzm)


#### Processing for Other Ocean Species

xmdata=subset(dmdata,rcat=="Ocean_Other")

xmdata$order[is.na(xmdata$order)]="NotAssigned"

#### Construction of Model Variable V1 From Range Area 

xmdata$nxside=ceiling((xmdata$area)^0.5)
xmdata$lnxside=log(xmdata$nxside)
xmdata$v1=xmdata$lnxside
mxv1=max(xmdata$v1,na.rm=TRUE)
xmdata$dv1=mxv1-xmdata$v1
mx1=max(xmdata$dv1,na.rm=TRUE)
xmdata$nfactor1=100*xmdata$dv1/mx1
xmdata$factor1="Range Size"
xmdata[,c("mxv1","dv1","mx1")]=NULL

#### Construction of Model Variable V2 From EEZ Coverage

xmdata$neezpct=100*xmdata$eezpct
xmdata$neezpct[xmdata$neezpct<1]=1
xmdata$v2=log(xmdata$neezpct)
mxv2=max(xmdata$v2,na.rm=TRUE)
xmdata$dv2=mxv2-xmdata$v2
mx2=max(xmdata$dv2,na.rm=TRUE)
xmdata$nfactor2=100*xmdata$dv2/mx2
xmdata$factor2="EEZ Coverage"
xmdata[,c("mxv2","dv2","mx2")]=NULL

#### Construction of Model Variable V3 From Coastal Population Impact

xmdata$v3=log(xmdata$popshadow+1)
mx3=max(xmdata$v3,na.rm=TRUE)
xmdata$v3=as.numeric(xmdata$v3)
xmdata$nfactor3=100*xmdata$v3/mx3
xmdata$factor3="Coastal Population"
xmdata[,c("mx3")]=NULL

#### Construction of Model Variable V4 From Formal Protection Status

xmdata$nparkpct=100*xmdata$parkpct
xmdata$nparkpct[xmdata$nparkpct<1]=1
xmdata$v4=log(xmdata$nparkpct)
mxv4=max(xmdata$v4,na.rm=TRUE)
xmdata$dv4=mxv4-xmdata$v4
mx4=max(xmdata$dv4,na.rm=TRUE)
xmdata$nfactor4=100*xmdata$dv4/mx4
xmdata$factor4="Formal Protection"
xmdata[,c("mxv4","dv4","mx4")]=NULL

tcounts=as.data.frame(table(xmdata$order))
names(tcounts)=c("order","freq")
xtcounts=subset(tcounts,order!="NotAssigned")
xtcounts=subset(xtcounts,freq>=100)

vor=xtcounts$order
unique_order <- vor

#### Create Dummy Variables for All Species Orders With At Least 100 Observations

for (order_name in unique_order) {
  dv <- ifelse(xmdata$order == order_name, 1, 0)
  dv[is.na(dv)]=0
  dvname <- paste("d_", order_name, sep = "_")
  xmdata[dvname] <- dv
}

dvnames <- grep("^d_", names(xmdata), value = TRUE)

#### Create Full Interaction Terms For Model Variables V1 to V4

xmdata <- xmdata %>%
  mutate(
    cp_v1_v2 = v1 * v2,
    cp_v1_v3 = v1 * v3,
    cp_v1_v4 = v1 * v4,
    cp_v2_v3 = v2 * v3,
    cp_v2_v4 = v2 * v4,
    cp_v3_v4 = v3 * v4,
    cp_v1_sq = v1^2,
    cp_v2_sq = v2^2,
    cp_v3_sq = v3^2,
    cp_v4_sq = v4^2
  )

dvcross=grep("^cp_", names(xmdata), value = TRUE)

#### Create IUCN-Based Risk Scores for Ordered Logit Regression

xmdata$iscore <- factor(xmdata$irisk, levels = c("1LC","2NT","3VU", "4EN", "5CR"))

xmdata$irisk=as.numeric(xmdata$iscore)

#### Estimate Simple and Fully-Specified Risk Models

rfact1="irisk ~ v1 + v2 + v3 + v4"
rfact=paste("irisk ~ v1 + v2 + v3 + v4 +",paste(dvnames, collapse = " + "),"+",paste(dvcross, collapse = " + "))

model <- lm(rfact1, xmdata)
summary(model)
model_Ocean_Other0 <- model

model <- lm(rfact, xmdata)
summary(model)
model_Ocean_Other1 <- model

models_marine_full_r2[2] <- summary(model)$r.squared

coefs<- coef(model)
mcoefs <- data.frame(variable = names(coefs), coef = coefs)
xmc=subset(mcoefs,is.na(coef))
xv=xmc$variable

#### Identify Collinear Species Order Dummy Variables to Exclude From Ordered Logit Estimation

dxnames=dvnames[!dvnames %in% xv]

#### Estimate the Ordered Logit Model

rfact=paste("iscore ~ v1 + v2 + v3 + v4 +",paste(dxnames, collapse = " + "),"+",paste(dvcross, collapse = " + "))
# rfact=paste("iscore ~ ",paste(dxnames, collapse = " + "),"+",paste(dvcross, collapse = " + "))

#mm=polr(iscore ~ v1 + v2 + v3 + v4 , data = xmdata, Hess = TRUE)
#summary(mm)

m=polr(rfact, data = xmdata, Hess = TRUE)

#### Predict Threat Probabilities For All Species in the Set"

pprob <- predict(m, xmdata, type = "probs")
zmdata=cbind(xmdata,pprob)
zmdata$tprob <- rowSums(zmdata[, c("2NT","3VU", "4EN", "5CR")])
zmdata$pthreat=plyr::round_any(100*zmdata$tprob,1)
#xzm=zmdata[,c("lcat","rcat","gdir","species","tprob","pthreat","nfactor1","factor1","nfactor2","factor2","nfactor3","factor3","nfactor4","factor4")]
xzm=zmdata[,c("lcat","rcat","species","tprob","pthreat","nfactor1","factor1","nfactor2","factor2","nfactor3","factor3","nfactor4","factor4")]

########################################################
##  Output factor data for Figure 11
########################################################

xmcmb=rbind(xmcmb,xzm)
dim(xmcmb)
xmname=file.path(wkdir,'local_data',sprintf("vers%s",ddh_vers),paste0("GBIF_Species_Threats_Factors",Sys.Date(),".csv"))
data.table::fwrite(xmcmb,xmname,row.names=FALSE)





########################################################
##  TABLE 1
########################################################



# create grouping for table
vcat <- c('Land_Amphibians','Land_Birds','Land_Mammals','Land_Reptiles','Land_Fish')
table(xmcmb$rcat)
species_threats <- xmcmb %>%
  mutate(loc_spp_grp = ifelse(rcat %in% vcat,'Land_Vertebrates', rcat)) %>%
  filter(loc_spp_grp %in% c('Land_Vertebrates','Land_Plants','Land_Other','Ocean_Fish','Ocean_Other')) %>%
  dplyr::select(lcat,loc_spp_grp,factor1,factor2,factor3,factor4,nfactor1,nfactor2,nfactor3,nfactor4)
dim(species_threats)
table(species_threats$loc_spp_grp)

result <- list()
groupvar <- unique(species_threats$loc_spp_grp)
for (i in 1:length(groupvar)){
  print(groupvar)
  group_i <- groupvar[i]
  
  cor_matrix <- species_threats %>%
    filter(loc_spp_grp==group_i) %>%
    dplyr::select(-c(lcat,loc_spp_grp,factor1,factor2,factor3,factor4)) %>%
    dplyr::rename(Factor1=nfactor1,
                  Factor2=nfactor2,
                  Factor3=nfactor3,
                  Factor4=nfactor4) %>%
    cor(use="pairwise.complete.obs",method='spearman')
  
  # two digits for publishing
  cor_matrix <-  formatC(signif(cor_matrix, digits=2), digits=2, format="fg", flag="#")
  
  # construct lower triangle as a subset of the full matrix
  lower_tri <- as.data.frame(as.table(cor_matrix)[lower.tri(cor_matrix)], stringsAsFactors = FALSE)
  names(lower_tri)[1] <- 'Correlation'
  lower_tri$Var1 <- rownames(cor_matrix)[row(cor_matrix)[lower.tri(cor_matrix)]]
  lower_tri$Var2 <- colnames(cor_matrix)[col(cor_matrix)[lower.tri(cor_matrix)]]
  
  # long to wide
  wide_cor_df <- lower_tri %>%
    tidyr::pivot_wider(names_from = Var2, values_from = Correlation) %>%
    as.data.frame()
  
  # add first row
  df0 <- as.data.table(x=c('Factor1'))
  colnames(df0)<-'Var1'
  wide_cor_df<- data.table::rbindlist(list(df0,wide_cor_df),fill=TRUE)
  
  # add groupvar
  wide_cor_df$groupvar <- group_i
  
  # add factor definition
  species_factors <- species_threats %>%
    dplyr::filter(loc_spp_grp==group_i) %>%
    dplyr::select(factor1,factor2,factor3,factor4) %>%
    dplyr::distinct() %>% as.character()
  wide_cor_df$factor_def <- species_factors
  
  # reorder columns
  wide_cor_df <- wide_cor_df %>%
    dplyr::select(groupvar,factor_def,Var1,Factor1,Factor2,Factor3)
  
  result[[i]]<- wide_cor_df
}

# build table from each group 
# eliminate subsequent words of location in table for presentation purposes
table1_df <- as.data.frame(data.table::rbindlist(result,fill=TRUE)) %>%
  separate(groupvar, into = c("Location", "Species"), sep = "_", remove = FALSE) %>%
  dplyr::select(!groupvar) %>%
  mutate(Location = ifelse(duplicated(Location) & lag(Location) == Location, NA, Location))

# eliminate subsequent words of species in table for presentation purposes
table1_df <- table1_df %>%
  mutate(Species = ifelse(duplicated(Species) & lag(Species) == Species, NA, Species))
colnames(table1_df) <- c('Location','Species','Factor Definition','','Factor1','Factor2','Factor3')  

# delete NA for presentation purposes
table1_df[is.na(table1_df)] <-""

# write csv
tableA1_df_fn <- file.path(tbldir,paste0('Table01_correlations_between_predictive_model_variables_',
                                         sprintf("vers%s_%s",ddh_vers,Sys.Date()),'.csv'))
write.csv(table1_df,tableA1_df_fn,row.names=FALSE)


########################################################
##  TABLE 2
########################################################


##
## TERRESTRIAL
##
require(modelsummary)

output_terrestrial_fn <- file.path(tbldir,paste0('table02a_ordered_logit_results_',
                                            sprintf("vers%s_%s",ddh_vers,Sys.Date()),'.docx'))


# order preserving match
land_groups_for_table <- c('Land_Vertebrates','Land_Plants','Land_Other')

'%ino%' <- function(x, table) {
  xSeq <- seq(along = x)
  names(xSeq) <- x
  Out <- xSeq[as.character(table)]
  Out[!is.na(Out)]
}

models_terrestrial_indices <- as.numeric(rland %ino% land_groups_for_table)
#models_terrestrial <- models_terrestrial[c(models_terrestrial_indices)]
terrestrial_model_list <- list('Vertebrates' = models_terrestrial[[c(models_terrestrial_indices)[1]]], 
                               'Plants' = models_terrestrial[[c(models_terrestrial_indices)[2]]],
                               'Other' = models_terrestrial[[c(models_terrestrial_indices)[3]]])

# add custom R2 based on FULL model
terr_r2full_df <- as.data.frame(t(c("R2 (Full)",unlist(sprintf(models_terrestrial_full_r2[c(models_terrestrial_indices)], fmt = '%#.3f')))))

terr_models <- modelsummary(
  terrestrial_model_list,
  coef_rename = c("v1" = "Range Size", 
                     "v2" = "Settlement Sensitivity",
                     "v3" = "Population Density",
                     "v4" = "Formal Protection"
                     ),
  coef_omit = c(1),
  fmt = 3,
  statistic = "({statistic}){stars}",
  stars = FALSE,
  gof_map = c("nobs", "r.squared"),
  add_rows = terr_r2full_df,
  notes = "Notes: Full model includes translog terms.",
  output=output_terrestrial_fn)


##
## MARINE
##
require(modelsummary)
names(model_Ocean_Fish0$coefficients)[2:5] <- c('Range Size','Exclusive Economic Zone','Fishing Intensity (1)','Fishing Intensity (2)')
names(model_Ocean_Other0$coefficients)[2:5] <- c('Range Size','Exclusive Economic Zone','Coastal Population Influence','Formal Protection')

output_marine_fn <- file.path(tbldir,paste0('table02b_ordered_logit_results_',
                                            sprintf("vers%s_%s",ddh_vers,Sys.Date()),'.docx'))
marine_model_list <- list("Fish" = model_Ocean_Fish0, "Other Species" = model_Ocean_Other0)

# add custom R2 based on FULL model
r2full_df <- as.data.frame(t(c("R2 (Full)",unlist(sprintf(models_marine_full_r2, fmt = '%#.3f')))))

# model summary table marine
marine_models <- modelsummary(
  marine_model_list,
  coef_omit = c(1),
  fmt = 3,
  stars = FALSE,
  statistic = "({statistic}){stars}",
  gof_map = c("nobs", "r.squared"),
  add_rows = r2full_df,
  notes = "Notes: Full model includes translog terms.",
  output=output_marine_fn)
