################################################################################
##
## Table 4: Species Occurrence Region sizes of top-ranking species 
## in the model-based composite indicator
##
################################################################################

species_tab_fn <- file.path(wkdir,'local_data',sprintf("vers%s",ddh_vers), "GBIF_Merged_IUCN_Risks_tab.csv")
species_tab <- readr::read_csv(species_tab_fn)
if(!('tprob' %in% names(species_tab))) {
  species_tab <- species_tab %>%
    dplyr::rename(.,tprob = pthreat)
}

spp_risks_full <- species_tab  %>%
  dplyr::select(species,irisk,area,tprob)

print(sprintf("Total species with tprob: %s",sum(!is.na(spp_risks_full$tprob))))
spp_risks_full <- spp_risks_full %>%
  dplyr::filter(!is.na(tprob))

scale_group_breaks <- c(0,20*20,50*50,100*100,200*200,max(spp_risks_full$area,na.rm=T))
scale_group_labels <- c(1,20,50,100,200)

print(sprintf("Total species with IUCN and tprob: %s",sum(!is.na(spp_risks_full$tprob))))
species_tab_grid <- spp_risks_full %>%
  dplyr::filter(!is.na(tprob) & !is.na(area)) %>%
  dplyr::mutate(range_categories = cut(area,
                                       scale_group_breaks,
                                       include.lowest=T,
                                       scale_group_labels))
sum(is.na(species_tab_grid$range_categories))
table(species_tab_grid$range_categories)

n_rangecat_0_400 = sum(species_tab_grid$range_categories=="1",na.rm=T)
species_tab_grid_scale_0_400 <- species_tab_grid %>%
  #dplyr::filter(area <= (200*200)) %>%
  dplyr::select(range_categories,tprob) %>% 
  dplyr::arrange(desc(tprob)) %>%
  top_n(n_rangecat_0_400) %>%
  dplyr::count(range_categories) %>% 
  mutate(prc = round(prop.table(n)*100,2)) %>%
  dplyr::rename(Count = n) 

tbl4df <- as.data.frame(species_tab_grid_scale_0_400)
names(tbl4df)[1] <- "Range size"
species_tab_grid_scale_fn <- file.path(tbldir,
                                       paste0('Table04_Range_size_of_top_rank_tprob_in_rangecat_0_200km',
                                                     '_ddh',ddh_vers,
                                                     'run',run_vers,'.csv'))
write.csv(tbl4df,species_tab_grid_scale_fn,row.names=FALSE)
